/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

import QtQuick 1.1
import com.nokia.meego 1.0
import com.cuteradio.models 1.0
import com.cuteradio.enums 1.0
import "file:///usr/lib/qt4/imports/com/nokia/meego/UIConstants.js" as UI

MyPage {
    id: root

    function showGenres() {
        genreModel.showGenres();
    }

    function showPodcastGenres() {
        genreModel.showPodcastGenres();
    }

    title: qsTr("Stations by genre")
    tools: ToolBarLayout {

        BackToolIcon {}

        NowPlayingButton {}
    }

    ListView {
        id: view

        anchors.fill: parent
        model: TuneInPairListModel {
            id: genreModel
        }
        delegate: TuneInGenreDelegate {
            onClicked: {
                var page = appWindow.pageStack.push(Qt.resolvedUrl("TuneInNameListPage.qml"), { title: name });

                switch (genreModel.queryType) {
                case Queries.PodcastGenres:
                    page.showPodcastNames(value, "p");
                    return;
                default:
                    page.showNames(value, "s");
                    return;
                }
            }
        }
        section.delegate: SectionDelegate {
            text: section
        }
        section.property: "section"
        section.criteria: ViewSection.FirstCharacter
    }

    MySectionScroller {
        listView: view
    }

    Label {
        anchors {
            fill: parent
            margins: UI.PADDING_DOUBLE
        }
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        wrapMode: Text.WordWrap
        color: UI.COLOR_INVERTED_SECONDARY_FOREGROUND
        font.bold: true
        font.pixelSize: 40
        text: qsTr("No genres found")
        visible: (!genreModel.count) && (!genreModel.loading)
    }

    BusyIndicator {
        anchors.centerIn: parent
        platformStyle: BusyIndicatorStyle {
            size: "large"
        }
        visible: genreModel.loading
        running: visible
    }
}
